#
# This is more of an integration test that requires a proper environment to run.
# Therefore, these specs are encapsulated by exception handling to contain a
# potential explosion!
#
# To run these specs, simply:
# 1. Set appropriate environment variables: PGDATABASE, PGHOST, PGPORT, PGUSER
# 2. Specify your database password in ~/.pgpass
#

begin
  require 'pg'
  require_relative 'state_store'

  PGTable = 'state'
  PGDB = PG::Connection.new
  PGDB.exec 'SET client_min_messages TO WARNING'
  PGDB.exec <<-SQL
    CREATE TEMPORARY TABLE #{PGTable} (
      token   varchar PRIMARY KEY,
      object  bytea NOT NULL,
      mtime   timestamp DEFAULT current_timestamp
    )
  SQL

  describe Rack::State::Store::Postgres do
    before { @store = Rack::State::Store::Postgres.new(PGDB, PGTable) }
    after { PGDB.exec "TRUNCATE TABLE #{PGTable}" }
    behaves_like Rack::State::Store
  end

  describe Rack::State::Store::PreparedPostgres do
    before { @store = Rack::State::Store::PreparedPostgres.new(PGDB, PGTable) }
    after { PGDB.exec "TRUNCATE TABLE #{PGTable}" }
    behaves_like Rack::State::Store
  end

  PGDB.close
rescue LoadError
  $stderr.puts 'Not running Postgres specs: cannot load the "pg" library.'
rescue PG::ConnectionBad
  $stderr.puts 'Not running Postgres specs: cannot connect to the database.'
end
