require 'rack/state'

#
# All Rack::State::Store adapters must include these specifications.
# Passing these specs guarantees compatibility with StateObject.
#
shared Rack::State::Store do
  @token = 'a-valid-token-name'
  @data  = 'example state data'

  it 'returns nil when reading state for a nonexistent token' do
    @store.read(@token).should.be.nil
  end

  it 'returns nil when deleting state for a nonexistent token' do
    @store.delete(@token).should.be.nil
  end

  it 'raises KeyError when updating state for nonexistent token' do
    should.raise(KeyError) { @store.update(@token, @data) }
  end

  it 'raises KeyError when creating state for existing token' do
    should.not.raise(KeyError) { @store.create(@token, @data) }
    should.    raise(KeyError) { @store.create(@token, @data) }
  end

  it 'executes the standard CRUD process as expected' do
    should.not.raise(KeyError) { @store.create(@token, @data) }
    @store.read(@token).should.equal @data
    should.not.raise(KeyError) { @store.update(@token, @data+'more') }
    @store.read(@token).should.equal @data+'more'
    @store.delete(@token)
    @store.read(@token).should.be.nil
  end
end
